==> aliyun-python-sdk-vod-2.16.5.tar.gz: aliyun-python-sdk-vod-2.16.5/aliyunsdkvod/request/v20170321/DeleteTranscodeTemplateGroupRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkvod.endpoint import endpoint_data

class DeleteTranscodeTemplateGroupRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DeleteTranscodeTemplateGroup','vod')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_TranscodeTemplateIds(self):
		return self.get_query_params().get('TranscodeTemplateIds')

	def set_TranscodeTemplateIds(self,TranscodeTemplateIds):
		self.add_query_param('TranscodeTemplateIds',TranscodeTemplateIds)

	def get_TranscodeTemplateGroupId(self):
		return self.get_query_params().get('TranscodeTemplateGroupId')

	def set_TranscodeTemplateGroupId(self,TranscodeTemplateGroupId):
		self.add_query_param('TranscodeTemplateGroupId',TranscodeTemplateGroupId)

	def get_ForceDelGroup(self):
		return self.get_query_params().get('ForceDelGroup')

	def set_ForceDelGroup(self,ForceDelGroup):
		self.add_query_param('ForceDelGroup',ForceDelGroup)

==> aliyun-python-sdk-vod-2.16.21.tar.gz: aliyun-python-sdk-vod-2.16.21/aliyunsdkvod/request/v20170321/DeleteTranscodeTemplateGroupRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkvod.endpoint import endpoint_data

class DeleteTranscodeTemplateGroupRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DeleteTranscodeTemplateGroup','vod')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_TranscodeTemplateIds(self): # String
		return self.get_query_params().get('TranscodeTemplateIds')

	def set_TranscodeTemplateIds(self, TranscodeTemplateIds):  # String
		self.add_query_param('TranscodeTemplateIds', TranscodeTemplateIds)
	def get_TranscodeTemplateGroupId(self): # String
		return self.get_query_params().get('TranscodeTemplateGroupId')

	def set_TranscodeTemplateGroupId(self, TranscodeTemplateGroupId):  # String
		self.add_query_param('TranscodeTemplateGroupId', TranscodeTemplateGroupId)
	def get_ForceDelGroup(self): # String
		return self.get_query_params().get('ForceDelGroup')

	def set_ForceDelGroup(self, ForceDelGroup):  # String
		self.add_query_param('ForceDelGroup', ForceDelGroup)
